# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_auction_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_auction_rpc.proto',
  package='injective_auction_rpc',
  syntax='proto3',
  serialized_options=b'Z\030/injective_auction_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$exchange/injective_auction_rpc.proto\x12\x15injective_auction_rpc\"\x1f\n\x0e\x41uctionRequest\x12\r\n\x05round\x18\x01 \x01(\x12\"l\n\x0f\x41uctionResponse\x12/\n\x07\x61uction\x18\x01 \x01(\x0b\x32\x1e.injective_auction_rpc.Auction\x12(\n\x04\x62ids\x18\x02 \x03(\x0b\x32\x1a.injective_auction_rpc.Bid\"\x9c\x01\n\x07\x41uction\x12\x0e\n\x06winner\x18\x01 \x01(\t\x12+\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32\x1b.injective_auction_rpc.Coin\x12\x1a\n\x12winning_bid_amount\x18\x03 \x01(\t\x12\r\n\x05round\x18\x04 \x01(\x04\x12\x15\n\rend_timestamp\x18\x05 \x01(\x12\x12\x12\n\nupdated_at\x18\x06 \x01(\x12\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"8\n\x03\x42id\x12\x0e\n\x06\x62idder\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"\x11\n\x0f\x41uctionsRequest\"D\n\x10\x41uctionsResponse\x12\x30\n\x08\x61uctions\x18\x01 \x03(\x0b\x32\x1e.injective_auction_rpc.Auction\"\x13\n\x11StreamBidsRequest\"Z\n\x12StreamBidsResponse\x12\x0e\n\x06\x62idder\x18\x01 \x01(\t\x12\x12\n\nbid_amount\x18\x02 \x01(\t\x12\r\n\x05round\x18\x03 \x01(\x04\x12\x11\n\ttimestamp\x18\x04 \x01(\x12\x32\xb9\x02\n\x13InjectiveAuctionRPC\x12`\n\x0f\x41uctionEndpoint\x12%.injective_auction_rpc.AuctionRequest\x1a&.injective_auction_rpc.AuctionResponse\x12[\n\x08\x41uctions\x12&.injective_auction_rpc.AuctionsRequest\x1a\'.injective_auction_rpc.AuctionsResponse\x12\x63\n\nStreamBids\x12(.injective_auction_rpc.StreamBidsRequest\x1a).injective_auction_rpc.StreamBidsResponse0\x01\x42\x1aZ\x18/injective_auction_rpcpbb\x06proto3'
)




_AUCTIONREQUEST = _descriptor.Descriptor(
  name='AuctionRequest',
  full_name='injective_auction_rpc.AuctionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='round', full_name='injective_auction_rpc.AuctionRequest.round', index=0,
      number=1, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=94,
)


_AUCTIONRESPONSE = _descriptor.Descriptor(
  name='AuctionResponse',
  full_name='injective_auction_rpc.AuctionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auction', full_name='injective_auction_rpc.AuctionResponse.auction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bids', full_name='injective_auction_rpc.AuctionResponse.bids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=204,
)


_AUCTION = _descriptor.Descriptor(
  name='Auction',
  full_name='injective_auction_rpc.Auction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='winner', full_name='injective_auction_rpc.Auction.winner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basket', full_name='injective_auction_rpc.Auction.basket', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='winning_bid_amount', full_name='injective_auction_rpc.Auction.winning_bid_amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective_auction_rpc.Auction.round', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='injective_auction_rpc.Auction.end_timestamp', index=4,
      number=5, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_auction_rpc.Auction.updated_at', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=207,
  serialized_end=363,
)


_COIN = _descriptor.Descriptor(
  name='Coin',
  full_name='injective_auction_rpc.Coin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective_auction_rpc.Coin.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective_auction_rpc.Coin.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=402,
)


_BID = _descriptor.Descriptor(
  name='Bid',
  full_name='injective_auction_rpc.Bid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bidder', full_name='injective_auction_rpc.Bid.bidder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective_auction_rpc.Bid.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_auction_rpc.Bid.timestamp', index=2,
      number=3, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=460,
)


_AUCTIONSREQUEST = _descriptor.Descriptor(
  name='AuctionsRequest',
  full_name='injective_auction_rpc.AuctionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=479,
)


_AUCTIONSRESPONSE = _descriptor.Descriptor(
  name='AuctionsResponse',
  full_name='injective_auction_rpc.AuctionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auctions', full_name='injective_auction_rpc.AuctionsResponse.auctions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=549,
)


_STREAMBIDSREQUEST = _descriptor.Descriptor(
  name='StreamBidsRequest',
  full_name='injective_auction_rpc.StreamBidsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=570,
)


_STREAMBIDSRESPONSE = _descriptor.Descriptor(
  name='StreamBidsResponse',
  full_name='injective_auction_rpc.StreamBidsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bidder', full_name='injective_auction_rpc.StreamBidsResponse.bidder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bid_amount', full_name='injective_auction_rpc.StreamBidsResponse.bid_amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective_auction_rpc.StreamBidsResponse.round', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_auction_rpc.StreamBidsResponse.timestamp', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=572,
  serialized_end=662,
)

_AUCTIONRESPONSE.fields_by_name['auction'].message_type = _AUCTION
_AUCTIONRESPONSE.fields_by_name['bids'].message_type = _BID
_AUCTION.fields_by_name['basket'].message_type = _COIN
_AUCTIONSRESPONSE.fields_by_name['auctions'].message_type = _AUCTION
DESCRIPTOR.message_types_by_name['AuctionRequest'] = _AUCTIONREQUEST
DESCRIPTOR.message_types_by_name['AuctionResponse'] = _AUCTIONRESPONSE
DESCRIPTOR.message_types_by_name['Auction'] = _AUCTION
DESCRIPTOR.message_types_by_name['Coin'] = _COIN
DESCRIPTOR.message_types_by_name['Bid'] = _BID
DESCRIPTOR.message_types_by_name['AuctionsRequest'] = _AUCTIONSREQUEST
DESCRIPTOR.message_types_by_name['AuctionsResponse'] = _AUCTIONSRESPONSE
DESCRIPTOR.message_types_by_name['StreamBidsRequest'] = _STREAMBIDSREQUEST
DESCRIPTOR.message_types_by_name['StreamBidsResponse'] = _STREAMBIDSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuctionRequest = _reflection.GeneratedProtocolMessageType('AuctionRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONREQUEST,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.AuctionRequest)
  })
_sym_db.RegisterMessage(AuctionRequest)

AuctionResponse = _reflection.GeneratedProtocolMessageType('AuctionResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONRESPONSE,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.AuctionResponse)
  })
_sym_db.RegisterMessage(AuctionResponse)

Auction = _reflection.GeneratedProtocolMessageType('Auction', (_message.Message,), {
  'DESCRIPTOR' : _AUCTION,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.Auction)
  })
_sym_db.RegisterMessage(Auction)

Coin = _reflection.GeneratedProtocolMessageType('Coin', (_message.Message,), {
  'DESCRIPTOR' : _COIN,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.Coin)
  })
_sym_db.RegisterMessage(Coin)

Bid = _reflection.GeneratedProtocolMessageType('Bid', (_message.Message,), {
  'DESCRIPTOR' : _BID,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.Bid)
  })
_sym_db.RegisterMessage(Bid)

AuctionsRequest = _reflection.GeneratedProtocolMessageType('AuctionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONSREQUEST,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.AuctionsRequest)
  })
_sym_db.RegisterMessage(AuctionsRequest)

AuctionsResponse = _reflection.GeneratedProtocolMessageType('AuctionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUCTIONSRESPONSE,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.AuctionsResponse)
  })
_sym_db.RegisterMessage(AuctionsResponse)

StreamBidsRequest = _reflection.GeneratedProtocolMessageType('StreamBidsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBIDSREQUEST,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.StreamBidsRequest)
  })
_sym_db.RegisterMessage(StreamBidsRequest)

StreamBidsResponse = _reflection.GeneratedProtocolMessageType('StreamBidsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBIDSRESPONSE,
  '__module__' : 'exchange.injective_auction_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_auction_rpc.StreamBidsResponse)
  })
_sym_db.RegisterMessage(StreamBidsResponse)


DESCRIPTOR._options = None

_INJECTIVEAUCTIONRPC = _descriptor.ServiceDescriptor(
  name='InjectiveAuctionRPC',
  full_name='injective_auction_rpc.InjectiveAuctionRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=665,
  serialized_end=978,
  methods=[
  _descriptor.MethodDescriptor(
    name='AuctionEndpoint',
    full_name='injective_auction_rpc.InjectiveAuctionRPC.AuctionEndpoint',
    index=0,
    containing_service=None,
    input_type=_AUCTIONREQUEST,
    output_type=_AUCTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Auctions',
    full_name='injective_auction_rpc.InjectiveAuctionRPC.Auctions',
    index=1,
    containing_service=None,
    input_type=_AUCTIONSREQUEST,
    output_type=_AUCTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamBids',
    full_name='injective_auction_rpc.InjectiveAuctionRPC.StreamBids',
    index=2,
    containing_service=None,
    input_type=_STREAMBIDSREQUEST,
    output_type=_STREAMBIDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEAUCTIONRPC)

DESCRIPTOR.services_by_name['InjectiveAuctionRPC'] = _INJECTIVEAUCTIONRPC

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/localhost/v1/localhost.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/lightclients/localhost/v1/localhost.proto',
  package='ibc.lightclients.localhost.v1',
  syntax='proto3',
  serialized_options=b'ZDgithub.com/cosmos/ibc-go/v2/modules/light-clients/09-localhost/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-ibc/lightclients/localhost/v1/localhost.proto\x12\x1dibc.lightclients.localhost.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\"l\n\x0b\x43lientState\x12%\n\x08\x63hain_id\x18\x01 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:\"chain_id\"\x12\x30\n\x06height\x18\x02 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\x42\x46ZDgithub.com/cosmos/ibc-go/v2/modules/light-clients/09-localhost/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,ibc_dot_core_dot_client_dot_v1_dot_client__pb2.DESCRIPTOR,])




_CLIENTSTATE = _descriptor.Descriptor(
  name='ClientState',
  full_name='ibc.lightclients.localhost.v1.ClientState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='ibc.lightclients.localhost.v1.ClientState.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\017yaml:\"chain_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='ibc.lightclients.localhost.v1.ClientState.height', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=243,
)

_CLIENTSTATE.fields_by_name['height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
DESCRIPTOR.message_types_by_name['ClientState'] = _CLIENTSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientState = _reflection.GeneratedProtocolMessageType('ClientState', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSTATE,
  '__module__' : 'ibc.lightclients.localhost.v1.localhost_pb2'
  # @@protoc_insertion_point(class_scope:ibc.lightclients.localhost.v1.ClientState)
  })
_sym_db.RegisterMessage(ClientState)


DESCRIPTOR._options = None
_CLIENTSTATE.fields_by_name['chain_id']._options = None
_CLIENTSTATE.fields_by_name['height']._options = None
_CLIENTSTATE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.gov.v1beta1 import gov_pb2 as cosmos_dot_gov_dot_v1beta1_dot_gov__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/gov/v1beta1/genesis.proto',
  package='cosmos.gov.v1beta1',
  syntax='proto3',
  serialized_options=b'Z(github.com/cosmos/cosmos-sdk/x/gov/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n cosmos/gov/v1beta1/genesis.proto\x12\x12\x63osmos.gov.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmos/gov/v1beta1/gov.proto\"\x8f\x04\n\x0cGenesisState\x12=\n\x14starting_proposal_id\x18\x01 \x01(\x04\x42\x1f\xf2\xde\x1f\x1byaml:\"starting_proposal_id\"\x12?\n\x08\x64\x65posits\x18\x02 \x03(\x0b\x32\x1b.cosmos.gov.v1beta1.DepositB\x10\xaa\xdf\x1f\x08\x44\x65posits\xc8\xde\x1f\x00\x12\x36\n\x05votes\x18\x03 \x03(\x0b\x32\x18.cosmos.gov.v1beta1.VoteB\r\xaa\xdf\x1f\x05Votes\xc8\xde\x1f\x00\x12\x42\n\tproposals\x18\x04 \x03(\x0b\x32\x1c.cosmos.gov.v1beta1.ProposalB\x11\xaa\xdf\x1f\tProposals\xc8\xde\x1f\x00\x12X\n\x0e\x64\x65posit_params\x18\x05 \x01(\x0b\x32!.cosmos.gov.v1beta1.DepositParamsB\x1d\xc8\xde\x1f\x00\xf2\xde\x1f\x15yaml:\"deposit_params\"\x12U\n\rvoting_params\x18\x06 \x01(\x0b\x32 .cosmos.gov.v1beta1.VotingParamsB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:\"voting_params\"\x12R\n\x0ctally_params\x18\x07 \x01(\x0b\x32\x1f.cosmos.gov.v1beta1.TallyParamsB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"tally_params\"B*Z(github.com/cosmos/cosmos-sdk/x/gov/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_gov_dot_v1beta1_dot_gov__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='cosmos.gov.v1beta1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='starting_proposal_id', full_name='cosmos.gov.v1beta1.GenesisState.starting_proposal_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\033yaml:\"starting_proposal_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposits', full_name='cosmos.gov.v1beta1.GenesisState.deposits', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\337\037\010Deposits\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes', full_name='cosmos.gov.v1beta1.GenesisState.votes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\337\037\005Votes\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposals', full_name='cosmos.gov.v1beta1.GenesisState.proposals', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\337\037\tProposals\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit_params', full_name='cosmos.gov.v1beta1.GenesisState.deposit_params', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\362\336\037\025yaml:\"deposit_params\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voting_params', full_name='cosmos.gov.v1beta1.GenesisState.voting_params', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\362\336\037\024yaml:\"voting_params\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tally_params', full_name='cosmos.gov.v1beta1.GenesisState.tally_params', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\362\336\037\023yaml:\"tally_params\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=636,
)

_GENESISSTATE.fields_by_name['deposits'].message_type = cosmos_dot_gov_dot_v1beta1_dot_gov__pb2._DEPOSIT
_GENESISSTATE.fields_by_name['votes'].message_type = cosmos_dot_gov_dot_v1beta1_dot_gov__pb2._VOTE
_GENESISSTATE.fields_by_name['proposals'].message_type = cosmos_dot_gov_dot_v1beta1_dot_gov__pb2._PROPOSAL
_GENESISSTATE.fields_by_name['deposit_params'].message_type = cosmos_dot_gov_dot_v1beta1_dot_gov__pb2._DEPOSITPARAMS
_GENESISSTATE.fields_by_name['voting_params'].message_type = cosmos_dot_gov_dot_v1beta1_dot_gov__pb2._VOTINGPARAMS
_GENESISSTATE.fields_by_name['tally_params'].message_type = cosmos_dot_gov_dot_v1beta1_dot_gov__pb2._TALLYPARAMS
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'cosmos.gov.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['starting_proposal_id']._options = None
_GENESISSTATE.fields_by_name['deposits']._options = None
_GENESISSTATE.fields_by_name['votes']._options = None
_GENESISSTATE.fields_by_name['proposals']._options = None
_GENESISSTATE.fields_by_name['deposit_params']._options = None
_GENESISSTATE.fields_by_name['voting_params']._options = None
_GENESISSTATE.fields_by_name['tally_params']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/channel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/core/channel/v1/channel.proto',
  package='ibc.core.channel.v1',
  syntax='proto3',
  serialized_options=b'Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!ibc/core/channel/v1/channel.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\"\xed\x01\n\x07\x43hannel\x12)\n\x05state\x18\x01 \x01(\x0e\x32\x1a.ibc.core.channel.v1.State\x12,\n\x08ordering\x18\x02 \x01(\x0e\x32\x1a.ibc.core.channel.v1.Order\x12=\n\x0c\x63ounterparty\x18\x03 \x01(\x0b\x32!.ibc.core.channel.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12\x33\n\x0f\x63onnection_hops\x18\x04 \x03(\tB\x1a\xf2\xde\x1f\x16yaml:\"connection_hops\"\x12\x0f\n\x07version\x18\x05 \x01(\t:\x04\x88\xa0\x1f\x00\"\x9c\x02\n\x11IdentifiedChannel\x12)\n\x05state\x18\x01 \x01(\x0e\x32\x1a.ibc.core.channel.v1.State\x12,\n\x08ordering\x18\x02 \x01(\x0e\x32\x1a.ibc.core.channel.v1.Order\x12=\n\x0c\x63ounterparty\x18\x03 \x01(\x0b\x32!.ibc.core.channel.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12\x33\n\x0f\x63onnection_hops\x18\x04 \x03(\tB\x1a\xf2\xde\x1f\x16yaml:\"connection_hops\"\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x0f\n\x07port_id\x18\x06 \x01(\t\x12\x12\n\nchannel_id\x18\x07 \x01(\t:\x04\x88\xa0\x1f\x00\"d\n\x0c\x43ounterparty\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\":\x04\x88\xa0\x1f\x00\"\x8e\x03\n\x06Packet\x12\x10\n\x08sequence\x18\x01 \x01(\x04\x12+\n\x0bsource_port\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"source_port\"\x12\x31\n\x0esource_channel\x18\x03 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"\x12\x35\n\x10\x64\x65stination_port\x18\x04 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"destination_port\"\x12;\n\x13\x64\x65stination_channel\x18\x05 \x01(\tB\x1e\xf2\xde\x1f\x1ayaml:\"destination_channel\"\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12Q\n\x0etimeout_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1d\xf2\xde\x1f\x15yaml:\"timeout_height\"\xc8\xde\x1f\x00\x12\x37\n\x11timeout_timestamp\x18\x08 \x01(\x04\x42\x1c\xf2\xde\x1f\x18yaml:\"timeout_timestamp\":\x04\x88\xa0\x1f\x00\"\x83\x01\n\x0bPacketState\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x10\n\x08sequence\x18\x03 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c:\x04\x88\xa0\x1f\x00\"@\n\x0f\x41\x63knowledgement\x12\x10\n\x06result\x18\x15 \x01(\x0cH\x00\x12\x0f\n\x05\x65rror\x18\x16 \x01(\tH\x00\x42\n\n\x08response*\xb7\x01\n\x05State\x12\x36\n\x1fSTATE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x11\x8a\x9d \rUNINITIALIZED\x12\x18\n\nSTATE_INIT\x10\x01\x1a\x08\x8a\x9d \x04INIT\x12\x1e\n\rSTATE_TRYOPEN\x10\x02\x1a\x0b\x8a\x9d \x07TRYOPEN\x12\x18\n\nSTATE_OPEN\x10\x03\x1a\x08\x8a\x9d \x04OPEN\x12\x1c\n\x0cSTATE_CLOSED\x10\x04\x1a\n\x8a\x9d \x06\x43LOSED\x1a\x04\x88\xa3\x1e\x00*w\n\x05Order\x12$\n\x16ORDER_NONE_UNSPECIFIED\x10\x00\x1a\x08\x8a\x9d \x04NONE\x12\"\n\x0fORDER_UNORDERED\x10\x01\x1a\r\x8a\x9d \tUNORDERED\x12\x1e\n\rORDER_ORDERED\x10\x02\x1a\x0b\x8a\x9d \x07ORDERED\x1a\x04\x88\xa3\x1e\x00\x42;Z9github.com/cosmos/ibc-go/v2/modules/core/04-channel/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,ibc_dot_core_dot_client_dot_v1_dot_client__pb2.DESCRIPTOR,])

_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='ibc.core.channel.v1.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNINITIALIZED_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\235 \rUNINITIALIZED',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_INIT', index=1, number=1,
      serialized_options=b'\212\235 \004INIT',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_TRYOPEN', index=2, number=2,
      serialized_options=b'\212\235 \007TRYOPEN',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_OPEN', index=3, number=3,
      serialized_options=b'\212\235 \004OPEN',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_CLOSED', index=4, number=4,
      serialized_options=b'\212\235 \006CLOSED',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\210\243\036\000',
  serialized_start=1344,
  serialized_end=1527,
)
_sym_db.RegisterEnumDescriptor(_STATE)

State = enum_type_wrapper.EnumTypeWrapper(_STATE)
_ORDER = _descriptor.EnumDescriptor(
  name='Order',
  full_name='ibc.core.channel.v1.Order',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ORDER_NONE_UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\235 \004NONE',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_UNORDERED', index=1, number=1,
      serialized_options=b'\212\235 \tUNORDERED',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_ORDERED', index=2, number=2,
      serialized_options=b'\212\235 \007ORDERED',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\210\243\036\000',
  serialized_start=1529,
  serialized_end=1648,
)
_sym_db.RegisterEnumDescriptor(_ORDER)

Order = enum_type_wrapper.EnumTypeWrapper(_ORDER)
STATE_UNINITIALIZED_UNSPECIFIED = 0
STATE_INIT = 1
STATE_TRYOPEN = 2
STATE_OPEN = 3
STATE_CLOSED = 4
ORDER_NONE_UNSPECIFIED = 0
ORDER_UNORDERED = 1
ORDER_ORDERED = 2



_CHANNEL = _descriptor.Descriptor(
  name='Channel',
  full_name='ibc.core.channel.v1.Channel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='ibc.core.channel.v1.Channel.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordering', full_name='ibc.core.channel.v1.Channel.ordering', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty', full_name='ibc.core.channel.v1.Channel.counterparty', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_hops', full_name='ibc.core.channel.v1.Channel.connection_hops', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"connection_hops\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ibc.core.channel.v1.Channel.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=351,
)


_IDENTIFIEDCHANNEL = _descriptor.Descriptor(
  name='IdentifiedChannel',
  full_name='ibc.core.channel.v1.IdentifiedChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='ibc.core.channel.v1.IdentifiedChannel.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordering', full_name='ibc.core.channel.v1.IdentifiedChannel.ordering', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty', full_name='ibc.core.channel.v1.IdentifiedChannel.counterparty', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_hops', full_name='ibc.core.channel.v1.IdentifiedChannel.connection_hops', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"connection_hops\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ibc.core.channel.v1.IdentifiedChannel.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.channel.v1.IdentifiedChannel.port_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='ibc.core.channel.v1.IdentifiedChannel.channel_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=638,
)


_COUNTERPARTY = _descriptor.Descriptor(
  name='Counterparty',
  full_name='ibc.core.channel.v1.Counterparty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.channel.v1.Counterparty.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"port_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='ibc.core.channel.v1.Counterparty.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"channel_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=640,
  serialized_end=740,
)


_PACKET = _descriptor.Descriptor(
  name='Packet',
  full_name='ibc.core.channel.v1.Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.core.channel.v1.Packet.sequence', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_port', full_name='ibc.core.channel.v1.Packet.source_port', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\022yaml:\"source_port\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_channel', full_name='ibc.core.channel.v1.Packet.source_channel', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"source_channel\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_port', full_name='ibc.core.channel.v1.Packet.destination_port', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\027yaml:\"destination_port\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_channel', full_name='ibc.core.channel.v1.Packet.destination_channel', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\032yaml:\"destination_channel\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ibc.core.channel.v1.Packet.data', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_height', full_name='ibc.core.channel.v1.Packet.timeout_height', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"timeout_height\"\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_timestamp', full_name='ibc.core.channel.v1.Packet.timeout_timestamp', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\030yaml:\"timeout_timestamp\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=1141,
)


_PACKETSTATE = _descriptor.Descriptor(
  name='PacketState',
  full_name='ibc.core.channel.v1.PacketState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.channel.v1.PacketState.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\016yaml:\"port_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='ibc.core.channel.v1.PacketState.channel_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"channel_id\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='ibc.core.channel.v1.PacketState.sequence', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ibc.core.channel.v1.PacketState.data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1275,
)


_ACKNOWLEDGEMENT = _descriptor.Descriptor(
  name='Acknowledgement',
  full_name='ibc.core.channel.v1.Acknowledgement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='ibc.core.channel.v1.Acknowledgement.result', index=0,
      number=21, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='ibc.core.channel.v1.Acknowledgement.error', index=1,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='ibc.core.channel.v1.Acknowledgement.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1277,
  serialized_end=1341,
)

_CHANNEL.fields_by_name['state'].enum_type = _STATE
_CHANNEL.fields_by_name['ordering'].enum_type = _ORDER
_CHANNEL.fields_by_name['counterparty'].message_type = _COUNTERPARTY
_IDENTIFIEDCHANNEL.fields_by_name['state'].enum_type = _STATE
_IDENTIFIEDCHANNEL.fields_by_name['ordering'].enum_type = _ORDER
_IDENTIFIEDCHANNEL.fields_by_name['counterparty'].message_type = _COUNTERPARTY
_PACKET.fields_by_name['timeout_height'].message_type = ibc_dot_core_dot_client_dot_v1_dot_client__pb2._HEIGHT
_ACKNOWLEDGEMENT.oneofs_by_name['response'].fields.append(
  _ACKNOWLEDGEMENT.fields_by_name['result'])
_ACKNOWLEDGEMENT.fields_by_name['result'].containing_oneof = _ACKNOWLEDGEMENT.oneofs_by_name['response']
_ACKNOWLEDGEMENT.oneofs_by_name['response'].fields.append(
  _ACKNOWLEDGEMENT.fields_by_name['error'])
_ACKNOWLEDGEMENT.fields_by_name['error'].containing_oneof = _ACKNOWLEDGEMENT.oneofs_by_name['response']
DESCRIPTOR.message_types_by_name['Channel'] = _CHANNEL
DESCRIPTOR.message_types_by_name['IdentifiedChannel'] = _IDENTIFIEDCHANNEL
DESCRIPTOR.message_types_by_name['Counterparty'] = _COUNTERPARTY
DESCRIPTOR.message_types_by_name['Packet'] = _PACKET
DESCRIPTOR.message_types_by_name['PacketState'] = _PACKETSTATE
DESCRIPTOR.message_types_by_name['Acknowledgement'] = _ACKNOWLEDGEMENT
DESCRIPTOR.enum_types_by_name['State'] = _STATE
DESCRIPTOR.enum_types_by_name['Order'] = _ORDER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Channel = _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), {
  'DESCRIPTOR' : _CHANNEL,
  '__module__' : 'ibc.core.channel.v1.channel_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.Channel)
  })
_sym_db.RegisterMessage(Channel)

IdentifiedChannel = _reflection.GeneratedProtocolMessageType('IdentifiedChannel', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIEDCHANNEL,
  '__module__' : 'ibc.core.channel.v1.channel_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.IdentifiedChannel)
  })
_sym_db.RegisterMessage(IdentifiedChannel)

Counterparty = _reflection.GeneratedProtocolMessageType('Counterparty', (_message.Message,), {
  'DESCRIPTOR' : _COUNTERPARTY,
  '__module__' : 'ibc.core.channel.v1.channel_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.Counterparty)
  })
_sym_db.RegisterMessage(Counterparty)

Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), {
  'DESCRIPTOR' : _PACKET,
  '__module__' : 'ibc.core.channel.v1.channel_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.Packet)
  })
_sym_db.RegisterMessage(Packet)

PacketState = _reflection.GeneratedProtocolMessageType('PacketState', (_message.Message,), {
  'DESCRIPTOR' : _PACKETSTATE,
  '__module__' : 'ibc.core.channel.v1.channel_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.PacketState)
  })
_sym_db.RegisterMessage(PacketState)

Acknowledgement = _reflection.GeneratedProtocolMessageType('Acknowledgement', (_message.Message,), {
  'DESCRIPTOR' : _ACKNOWLEDGEMENT,
  '__module__' : 'ibc.core.channel.v1.channel_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.channel.v1.Acknowledgement)
  })
_sym_db.RegisterMessage(Acknowledgement)


DESCRIPTOR._options = None
_STATE._options = None
_STATE.values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._options = None
_STATE.values_by_name["STATE_INIT"]._options = None
_STATE.values_by_name["STATE_TRYOPEN"]._options = None
_STATE.values_by_name["STATE_OPEN"]._options = None
_STATE.values_by_name["STATE_CLOSED"]._options = None
_ORDER._options = None
_ORDER.values_by_name["ORDER_NONE_UNSPECIFIED"]._options = None
_ORDER.values_by_name["ORDER_UNORDERED"]._options = None
_ORDER.values_by_name["ORDER_ORDERED"]._options = None
_CHANNEL.fields_by_name['counterparty']._options = None
_CHANNEL.fields_by_name['connection_hops']._options = None
_CHANNEL._options = None
_IDENTIFIEDCHANNEL.fields_by_name['counterparty']._options = None
_IDENTIFIEDCHANNEL.fields_by_name['connection_hops']._options = None
_IDENTIFIEDCHANNEL._options = None
_COUNTERPARTY.fields_by_name['port_id']._options = None
_COUNTERPARTY.fields_by_name['channel_id']._options = None
_COUNTERPARTY._options = None
_PACKET.fields_by_name['source_port']._options = None
_PACKET.fields_by_name['source_channel']._options = None
_PACKET.fields_by_name['destination_port']._options = None
_PACKET.fields_by_name['destination_channel']._options = None
_PACKET.fields_by_name['timeout_height']._options = None
_PACKET.fields_by_name['timeout_timestamp']._options = None
_PACKET._options = None
_PACKETSTATE.fields_by_name['port_id']._options = None
_PACKETSTATE.fields_by_name['channel_id']._options = None
_PACKETSTATE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from injective.wasmx.v1 import genesis_pb2 as injective_dot_wasmx_dot_v1_dot_genesis__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/wasmx/v1/query.proto',
  package='injective.wasmx.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1einjective/wasmx/v1/query.proto\x12\x12injective.wasmx.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a injective/wasmx/v1/genesis.proto\x1a\x14gogoproto/gogo.proto\"\x19\n\x17QueryWasmxParamsRequest\"L\n\x18QueryWasmxParamsResponse\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.wasmx.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x19\n\x17QueryModuleStateRequest\"K\n\x18QueryModuleStateResponse\x12/\n\x05state\x18\x01 \x01(\x0b\x32 .injective.wasmx.v1.GenesisState2\xb0\x02\n\x05Query\x12\x8c\x01\n\x0bWasmxParams\x12+.injective.wasmx.v1.QueryWasmxParamsRequest\x1a,.injective.wasmx.v1.QueryWasmxParamsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/injective/wasmx/v1/params\x12\x97\x01\n\x10WasmxModuleState\x12+.injective.wasmx.v1.QueryModuleStateRequest\x1a,.injective.wasmx.v1.QueryModuleStateResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /injective/wasmx/v1/module_stateBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,injective_dot_wasmx_dot_v1_dot_wasmx__pb2.DESCRIPTOR,injective_dot_wasmx_dot_v1_dot_genesis__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_QUERYWASMXPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryWasmxParamsRequest',
  full_name='injective.wasmx.v1.QueryWasmxParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=197,
)


_QUERYWASMXPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryWasmxParamsResponse',
  full_name='injective.wasmx.v1.QueryWasmxParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.wasmx.v1.QueryWasmxParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=199,
  serialized_end=275,
)


_QUERYMODULESTATEREQUEST = _descriptor.Descriptor(
  name='QueryModuleStateRequest',
  full_name='injective.wasmx.v1.QueryModuleStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=302,
)


_QUERYMODULESTATERESPONSE = _descriptor.Descriptor(
  name='QueryModuleStateResponse',
  full_name='injective.wasmx.v1.QueryModuleStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.wasmx.v1.QueryModuleStateResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=379,
)

_QUERYWASMXPARAMSRESPONSE.fields_by_name['params'].message_type = injective_dot_wasmx_dot_v1_dot_wasmx__pb2._PARAMS
_QUERYMODULESTATERESPONSE.fields_by_name['state'].message_type = injective_dot_wasmx_dot_v1_dot_genesis__pb2._GENESISSTATE
DESCRIPTOR.message_types_by_name['QueryWasmxParamsRequest'] = _QUERYWASMXPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryWasmxParamsResponse'] = _QUERYWASMXPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryModuleStateRequest'] = _QUERYMODULESTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryModuleStateResponse'] = _QUERYMODULESTATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryWasmxParamsRequest = _reflection.GeneratedProtocolMessageType('QueryWasmxParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYWASMXPARAMSREQUEST,
  '__module__' : 'injective.wasmx.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.wasmx.v1.QueryWasmxParamsRequest)
  })
_sym_db.RegisterMessage(QueryWasmxParamsRequest)

QueryWasmxParamsResponse = _reflection.GeneratedProtocolMessageType('QueryWasmxParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYWASMXPARAMSRESPONSE,
  '__module__' : 'injective.wasmx.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.wasmx.v1.QueryWasmxParamsResponse)
  })
_sym_db.RegisterMessage(QueryWasmxParamsResponse)

QueryModuleStateRequest = _reflection.GeneratedProtocolMessageType('QueryModuleStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATEREQUEST,
  '__module__' : 'injective.wasmx.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.wasmx.v1.QueryModuleStateRequest)
  })
_sym_db.RegisterMessage(QueryModuleStateRequest)

QueryModuleStateResponse = _reflection.GeneratedProtocolMessageType('QueryModuleStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATERESPONSE,
  '__module__' : 'injective.wasmx.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.wasmx.v1.QueryModuleStateResponse)
  })
_sym_db.RegisterMessage(QueryModuleStateResponse)


DESCRIPTOR._options = None
_QUERYWASMXPARAMSRESPONSE.fields_by_name['params']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='injective.wasmx.v1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=382,
  serialized_end=686,
  methods=[
  _descriptor.MethodDescriptor(
    name='WasmxParams',
    full_name='injective.wasmx.v1.Query.WasmxParams',
    index=0,
    containing_service=None,
    input_type=_QUERYWASMXPARAMSREQUEST,
    output_type=_QUERYWASMXPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/injective/wasmx/v1/params',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WasmxModuleState',
    full_name='injective.wasmx.v1.Query.WasmxModuleState',
    index=1,
    containing_service=None,
    input_type=_QUERYMODULESTATEREQUEST,
    output_type=_QUERYMODULESTATERESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /injective/wasmx/v1/module_state',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_oracle_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_oracle_rpc.proto',
  package='injective_oracle_rpc',
  syntax='proto3',
  serialized_options=b'Z\027/injective_oracle_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#exchange/injective_oracle_rpc.proto\x12\x14injective_oracle_rpc\"\x13\n\x11OracleListRequest\"C\n\x12OracleListResponse\x12-\n\x07oracles\x18\x01 \x03(\x0b\x32\x1c.injective_oracle_rpc.Oracle\"g\n\x06Oracle\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x13\n\x0b\x62\x61se_symbol\x18\x02 \x01(\t\x12\x14\n\x0cquote_symbol\x18\x03 \x01(\t\x12\x13\n\x0boracle_type\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\"k\n\x0cPriceRequest\x12\x13\n\x0b\x62\x61se_symbol\x18\x01 \x01(\t\x12\x14\n\x0cquote_symbol\x18\x02 \x01(\t\x12\x13\n\x0boracle_type\x18\x03 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x04 \x01(\r\"\x1e\n\rPriceResponse\x12\r\n\x05price\x18\x01 \x01(\t\"U\n\x13StreamPricesRequest\x12\x13\n\x0b\x62\x61se_symbol\x18\x01 \x01(\t\x12\x14\n\x0cquote_symbol\x18\x02 \x01(\t\x12\x13\n\x0boracle_type\x18\x03 \x01(\t\"8\n\x14StreamPricesResponse\x12\r\n\x05price\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x12\x32\xb0\x02\n\x12InjectiveOracleRPC\x12_\n\nOracleList\x12\'.injective_oracle_rpc.OracleListRequest\x1a(.injective_oracle_rpc.OracleListResponse\x12P\n\x05Price\x12\".injective_oracle_rpc.PriceRequest\x1a#.injective_oracle_rpc.PriceResponse\x12g\n\x0cStreamPrices\x12).injective_oracle_rpc.StreamPricesRequest\x1a*.injective_oracle_rpc.StreamPricesResponse0\x01\x42\x19Z\x17/injective_oracle_rpcpbb\x06proto3'
)




_ORACLELISTREQUEST = _descriptor.Descriptor(
  name='OracleListRequest',
  full_name='injective_oracle_rpc.OracleListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=80,
)


_ORACLELISTRESPONSE = _descriptor.Descriptor(
  name='OracleListResponse',
  full_name='injective_oracle_rpc.OracleListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oracles', full_name='injective_oracle_rpc.OracleListResponse.oracles', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=149,
)


_ORACLE = _descriptor.Descriptor(
  name='Oracle',
  full_name='injective_oracle_rpc.Oracle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective_oracle_rpc.Oracle.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_symbol', full_name='injective_oracle_rpc.Oracle.base_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_symbol', full_name='injective_oracle_rpc.Oracle.quote_symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_oracle_rpc.Oracle.oracle_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_oracle_rpc.Oracle.price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=254,
)


_PRICEREQUEST = _descriptor.Descriptor(
  name='PriceRequest',
  full_name='injective_oracle_rpc.PriceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_symbol', full_name='injective_oracle_rpc.PriceRequest.base_symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_symbol', full_name='injective_oracle_rpc.PriceRequest.quote_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_oracle_rpc.PriceRequest.oracle_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective_oracle_rpc.PriceRequest.oracle_scale_factor', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=363,
)


_PRICERESPONSE = _descriptor.Descriptor(
  name='PriceResponse',
  full_name='injective_oracle_rpc.PriceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_oracle_rpc.PriceResponse.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=395,
)


_STREAMPRICESREQUEST = _descriptor.Descriptor(
  name='StreamPricesRequest',
  full_name='injective_oracle_rpc.StreamPricesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_symbol', full_name='injective_oracle_rpc.StreamPricesRequest.base_symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_symbol', full_name='injective_oracle_rpc.StreamPricesRequest.quote_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_oracle_rpc.StreamPricesRequest.oracle_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=482,
)


_STREAMPRICESRESPONSE = _descriptor.Descriptor(
  name='StreamPricesResponse',
  full_name='injective_oracle_rpc.StreamPricesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective_oracle_rpc.StreamPricesResponse.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='injective_oracle_rpc.StreamPricesResponse.timestamp', index=1,
      number=2, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=540,
)

_ORACLELISTRESPONSE.fields_by_name['oracles'].message_type = _ORACLE
DESCRIPTOR.message_types_by_name['OracleListRequest'] = _ORACLELISTREQUEST
DESCRIPTOR.message_types_by_name['OracleListResponse'] = _ORACLELISTRESPONSE
DESCRIPTOR.message_types_by_name['Oracle'] = _ORACLE
DESCRIPTOR.message_types_by_name['PriceRequest'] = _PRICEREQUEST
DESCRIPTOR.message_types_by_name['PriceResponse'] = _PRICERESPONSE
DESCRIPTOR.message_types_by_name['StreamPricesRequest'] = _STREAMPRICESREQUEST
DESCRIPTOR.message_types_by_name['StreamPricesResponse'] = _STREAMPRICESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OracleListRequest = _reflection.GeneratedProtocolMessageType('OracleListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORACLELISTREQUEST,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.OracleListRequest)
  })
_sym_db.RegisterMessage(OracleListRequest)

OracleListResponse = _reflection.GeneratedProtocolMessageType('OracleListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORACLELISTRESPONSE,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.OracleListResponse)
  })
_sym_db.RegisterMessage(OracleListResponse)

Oracle = _reflection.GeneratedProtocolMessageType('Oracle', (_message.Message,), {
  'DESCRIPTOR' : _ORACLE,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.Oracle)
  })
_sym_db.RegisterMessage(Oracle)

PriceRequest = _reflection.GeneratedProtocolMessageType('PriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _PRICEREQUEST,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.PriceRequest)
  })
_sym_db.RegisterMessage(PriceRequest)

PriceResponse = _reflection.GeneratedProtocolMessageType('PriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _PRICERESPONSE,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.PriceResponse)
  })
_sym_db.RegisterMessage(PriceResponse)

StreamPricesRequest = _reflection.GeneratedProtocolMessageType('StreamPricesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPRICESREQUEST,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.StreamPricesRequest)
  })
_sym_db.RegisterMessage(StreamPricesRequest)

StreamPricesResponse = _reflection.GeneratedProtocolMessageType('StreamPricesResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPRICESRESPONSE,
  '__module__' : 'exchange.injective_oracle_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_oracle_rpc.StreamPricesResponse)
  })
_sym_db.RegisterMessage(StreamPricesResponse)


DESCRIPTOR._options = None

_INJECTIVEORACLERPC = _descriptor.ServiceDescriptor(
  name='InjectiveOracleRPC',
  full_name='injective_oracle_rpc.InjectiveOracleRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=543,
  serialized_end=847,
  methods=[
  _descriptor.MethodDescriptor(
    name='OracleList',
    full_name='injective_oracle_rpc.InjectiveOracleRPC.OracleList',
    index=0,
    containing_service=None,
    input_type=_ORACLELISTREQUEST,
    output_type=_ORACLELISTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Price',
    full_name='injective_oracle_rpc.InjectiveOracleRPC.Price',
    index=1,
    containing_service=None,
    input_type=_PRICEREQUEST,
    output_type=_PRICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamPrices',
    full_name='injective_oracle_rpc.InjectiveOracleRPC.StreamPrices',
    index=2,
    containing_service=None,
    input_type=_STREAMPRICESREQUEST,
    output_type=_STREAMPRICESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEORACLERPC)

DESCRIPTOR.services_by_name['InjectiveOracleRPC'] = _INJECTIVEORACLERPC

# @@protoc_insertion_point(module_scope)
